zope.security.testing — zope.security 4.0dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- zope.security 4.0dev documentation »

# `zope.security.testing`

Testing support code

This module provides some helper/stub objects for setting up interactions.

`zope.security.testing.` `addCheckerPublic`()

  Add the CheckerPublic permission as ‘zope.Public’

### Navigation

- index
- modules |
- next |
- previous |
- zope.security 4.0dev documentation »